<?php

/**
 * @file
 * Contains Batch API callbacks used during installation.
 */

/**
 * BatchAPI callback.
 */
function _dvg_enable_module($module, $module_name, &$context) {
  module_enable(array($module), FALSE);
  $context['message'] = st('Installed %module module.', array('%module' => $module_name));
}

/**
 * BatchAPI callback.
 */
function _dvg_flush_caches($operation, &$context) {
  $context['message'] = t('@operation', array('@operation' => $operation));
  drupal_flush_all_caches();
}


/**
 * BatchAPI callback.
 */
function _dvg_install_set_default_settings($operation, &$context) {
  $context['message'] = t('@operation', array('@operation' => $operation));
  variable_set('i18n_string_source_language', 'en');
  variable_set('date_first_day', 1); // First day of week: monday.
}

/**
 * BatchAPI callback.
 */
function _dvg_install_enable_dvg_theme($operation, &$context) {
  $context['message'] = t('@operation', array('@operation' => $operation));
  theme_disable(array('bartik'));
  theme_enable(array('dvg'));
  variable_set('theme_default', 'dvg');
  variable_set('admin_theme', 'seven');
  variable_set('node_admin_theme', TRUE);
}

/**
 * BatchAPI callback.
 */
function _dvg_install_disable_file_types($operation, &$context) {
  $context['message'] = t('@operation', array('@operation' => $operation));
  if (function_exists('file_type_disable')) {
    $file_types = array('image', 'video', 'audio', 'document');
    foreach ($file_types as $file_type) {
      file_type_disable($file_type);
    }
  }
}

/**
 * BatchAPI callback.
 */
function _dvg_install_import_dvg_translations($operation, &$context) {
  $context['message'] = t('@operation', array('@operation' => $operation));
  module_load_install('dvg_global');
  _dvg_global_import_translations(__DIR__ . '/translations/' . basename(__FILE__, '.profile') . '.nl.po');
}

/**
 * BatchAPI callback.
 */
function _dvg_install_revert_all_features($operation, &$context) {
  $context['message'] = t('@operation', array('@operation' => $operation));
  features_rebuild();
  features_revert();
}

/**
 * BatchAPI callback.
 */
function _dvg_menu_import_file($menu, &$context) {
  $context['message'] = st('Installed menu %menu.', array('%menu' => $menu));
  $path = drupal_get_path('module', 'dvg_demo_content');
  $file = $path . '/' . $menu . '-export.txt';
  menu_import_file($file, $menu, array(
    'link_to_content' => TRUE,
    'create_content' => FALSE,
    'remove_menu_items' => FALSE,
  ));
}
